@@ -369,7 +369,7 @@ Value RunConfig(const FunctionCallNode* function,
 
   // Create the new config.
   std::unique_ptr<Config> config = std::make_unique<Config>(
-      scope->settings(), label, scope->build_dependency_files());
+      scope->settings(), label, scope->CollectBuildDependencyFiles());
   config->set_defined_from(function);
   if (!Visibility::FillItemVisibility(config.get(), scope, err))
     return Value();
@@ -909,7 +909,7 @@ Value RunPool(const FunctionCallNode* function,
 
   // Create the new pool.
   std::unique_ptr<Pool> pool = std::make_unique<Pool>(
-      scope->settings(), label, scope->build_dependency_files());
+      scope->settings(), label, scope->CollectBuildDependencyFiles());
 
   if (label.name() == "console") {
     const Settings* settings = scope->settings();
@@ -1029,8 +1029,8 @@ Value RunPrintStackTrace(Scope* scope,
   std::string location_str = function->GetRange().begin().Describe(false);
   std::string toolchain =
       scope->settings()->toolchain_label().GetUserVisibleName(false);
-  std::string output =
-      "print_stack_trace() initiated at:  " + location_str + "  using: " + toolchain;
+  std::string output = "print_stack_trace() initiated at:  " + location_str +
+                       "  using: " + toolchain;
   output.push_back('\n');
 
   for (const auto& entry : scope->GetTemplateInvocationEntries()) {
@@ -1465,6 +1465,8 @@ struct FunctionInfoInitializer {
     INSERT_FUNCTION(ExecScript, false)
     INSERT_FUNCTION(FilterExclude, false)
     INSERT_FUNCTION(FilterInclude, false)
+    INSERT_FUNCTION(FilterLabelsInclude, false)
+    INSERT_FUNCTION(FilterLabelsExclude, false)
     INSERT_FUNCTION(ForEach, false)
     INSERT_FUNCTION(ForwardVariablesFrom, false)
     INSERT_FUNCTION(GetEnv, false)
@@ -1472,7 +1474,10 @@ struct FunctionInfoInitializer {
     INSERT_FUNCTION(GetPathInfo, false)
     INSERT_FUNCTION(GetTargetOutputs, false)
     INSERT_FUNCTION(Import, false)
+    INSERT_FUNCTION(LabelMatches, false)
+    INSERT_FUNCTION(Len, false)
     INSERT_FUNCTION(NotNeeded, false)
+    INSERT_FUNCTION(PathExists, false)
     INSERT_FUNCTION(Pool, false)
     INSERT_FUNCTION(Print, false)
     INSERT_FUNCTION(PrintStackTrace, false)
@@ -1528,7 +1533,7 @@ Value RunFunction(Scope* scope,
   if (found_function->second.self_evaluating_args_runner) {
     // Self evaluating args functions are special weird built-ins like foreach.
     // Rather than force them all to check that they have a block or no block
-    // and risk bugs for new additions, check a whitelist here.
+    // and risk bugs for new additions, check an allowlist here.
     if (found_function->second.self_evaluating_args_runner != &RunForEach) {
       if (!VerifyNoBlockForFunctionCall(function, block, err))
         return Value();
