@@ -58,22 +58,21 @@ Scope::Scope(Scope* parent)
       mutable_containing_(parent),
       settings_(parent->settings()),
       mode_flags_(0),
-      item_collector_(nullptr),
-      build_dependency_files_(parent->build_dependency_files_) {}
+      item_collector_(nullptr) {}
 
 Scope::Scope(const Scope* parent)
     : const_containing_(parent),
       mutable_containing_(nullptr),
       settings_(parent->settings()),
       mode_flags_(0),
-      item_collector_(nullptr),
-      build_dependency_files_(parent->build_dependency_files_) {}
+      item_collector_(nullptr) {}
 
 Scope::~Scope() = default;
 
 void Scope::DetachFromContaining() {
   const_containing_ = nullptr;
   mutable_containing_ = nullptr;
+  build_dependency_files_ = CollectBuildDependencyFiles();
 }
 
 bool Scope::HasValues(SearchNested search_nested) const {
@@ -209,6 +208,29 @@ const Template* Scope::GetTemplate(const std::string& name) const {
   return nullptr;
 }
 
+SourceFileSet Scope::CollectBuildDependencyFiles() const {
+  SourceFileSet result;
+
+  // Compute capacity first.
+  size_t capacity = 0;
+  const Scope* scope = this;
+  do {
+    capacity += scope->build_dependency_files_.size();
+    scope = scope->containing();
+  } while (scope);
+
+  result.reserve(capacity);
+
+  scope = this;
+  do {
+    result.insert(scope->build_dependency_files_.begin(),
+                  scope->build_dependency_files_.end());
+    scope = scope->containing();
+  } while (scope);
+
+  return result;
+}
+
 void Scope::MarkUsed(std::string_view ident) {
   RecordMap::iterator found = values_.find(ident);
   if (found == values_.end()) {
@@ -259,11 +281,9 @@ bool Scope::CheckForUnusedVars(Err* err) const {
           "You set the variable \"" + std::string(pair.first) +
           "\" here and it was unused before it went\nout of scope.";
 
-
       // Gather the template invocations that led up to this scope.
       auto entries = GetTemplateInvocationEntries();
       if (entries.size() != 0) {
-
         help.append("\n\nVia these template invocations:\n");
         for (const auto& entry : entries) {
           help.append("  " + entry.Describe() + "\n");
@@ -583,7 +603,8 @@ void Scope::SetTemplateInvocationEntry(std::string template_name,
                               std::move(location)});
 }
 
-const Scope::TemplateInvocationEntry* Scope::FindTemplateInvocationEntry() const {
+const Scope::TemplateInvocationEntry* Scope::FindTemplateInvocationEntry()
+    const {
   if (template_invocation_entry_)
     return template_invocation_entry_.get();
   if (const Scope* scope = containing())
@@ -593,7 +614,6 @@ const Scope::TemplateInvocationEntry* Scope::FindTemplateInvocationEntry() const
 
 void Scope::AppendTemplateInvocationEntries(
     std::vector<TemplateInvocationEntry>* out) const {
-
   const Value* invoker = GetValue("invoker");
   if (invoker && invoker->type() == Value::SCOPE)
     invoker->scope_value()->AppendTemplateInvocationEntries(out);
