@@ -625,10 +625,8 @@ bool Setup::FillArgsFromArgsInputFile(Err* err) {
   }
 
   Scope arg_scope(&dotfile_settings_);
-  // Set soure dir so relative imports in args work.
-  SourceDir root_source_dir =
-      SourceDirForCurrentDirectory(build_settings_.root_path());
-  arg_scope.set_source_dir(root_source_dir);
+  // Set source dir so relative imports in args work.
+  arg_scope.set_source_dir(args_input_file_->dir());
   args_root_->Execute(&arg_scope, err);
   if (err->has_error()) {
     return false;
@@ -1186,5 +1184,16 @@ bool Setup::FillOtherConfig(const base::CommandLine& cmdline, Err* err) {
     export_compile_commands_.push_back(std::move(pat));
   }
 
+  // Async non-linkable deps.
+  const Value* async_non_linkable_deps =
+      dotfile_scope_.GetValue("async_non_linkable_deps", true);
+  if (async_non_linkable_deps) {
+    if (!async_non_linkable_deps->VerifyTypeIs(Value::BOOLEAN, err)) {
+      return false;
+    }
+    build_settings_.set_async_non_linkable_deps(
+        async_non_linkable_deps->boolean_value());
+  }
+
   return true;
 }
